==> haskell-yesod-core-1.6.16-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.16
id: yesod-core-1.6.16-7HNIPMfL0aZE7C4w2n8DAf
key: yesod-core-1.6.16-7HNIPMfL0aZE7C4w2n8DAf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: ff8e546289e4c4f4ed0902f1dc55bd8f
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.16
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-core-1.6.16
hs-libraries: HSyesod-core-1.6.16-7HNIPMfL0aZE7C4w2n8DAf
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    auto-update-0.1.6-9RP5DxOJUcf75OPqVMWXul base-4.12.0.0
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    clientsession-0.9.1.2-CyhdhgSeYEC1l1xLO5XPLH
    conduit-1.3.1.1-6wGhn7vdA3B6uXWcLIr87M
    conduit-extra-1.3.4-K6FXFWghk929uw0H6vW1f containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    fast-logger-2.4.16-BphF1Z6pLYZ9rJKH5Zk5dn
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    monad-logger-0.3.30-8kfAoQrwnB6BgHMikQMr1E mtl-2.2.2
    parsec-3.1.13.0 path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    shakespeare-2.0.21-2LOxZglsNEK6waTgvreNvH template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-extra-3.0.28-F2XLLZJGOHkHVDuOrzgtkZ
    wai-logger-2.3.5-7cINmBOtDZcFx9boGarHiP
    warp-3.3.0-FHqAhJel0fYvrQY43eamp word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.17-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.6.17
id: yesod-core-1.6.17-IfKo9B8PbmWFE6igxnJQOa
key: yesod-core-1.6.17-IfKo9B8PbmWFE6igxnJQOa
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
abi: 1b1611fa77ab67d1498648e8e20f8c1d
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-core-1.6.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-core-1.6.17
hs-libraries: HSyesod-core-1.6.17-IfKo9B8PbmWFE6igxnJQOa
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    auto-update-0.1.6-6HwoHb0UkWSDuW69IvZChU base-4.12.0.0
    blaze-html-0.9.1.2-HwoBmHvd8MidwTYIDsO4n
    blaze-markup-0.8.2.3-ATcS0IRQcDMCxhB8vW9N1d bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    clientsession-0.9.1.2-EM3b0Z05jU5GAgTvKJTt2
    conduit-1.3.1.1-223VZeefHKZIaNcv3a4V93
    conduit-extra-1.3.4-GNv58rt6JAeUYsVx1bztm containers-0.6.0.1
    cookie-0.4.5-G7Q94cRAamcIKEZucf4yoC deepseq-1.4.4.0
    fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    monad-logger-0.3.31-ImvkmNSkLZ43nmZqqVd6b0 mtl-2.2.2
    parsec-3.1.13.0 path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    shakespeare-2.0.23-DSplswuwE23Detqyo7k6pM template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-extra-3.0.28-G1GZQLp66ug2OMsgLytpZV
    wai-logger-2.3.6-9w7uh45sRSSL1OLn3vwTB0
    warp-3.3.4-Ks8B4cPlDDQG26QixHAf6n
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
